Test

Struct Test 

pub struct Test<'b> { /* private fields */ }
A test target.

Implementations

Source

impl Test<'_>

pub fn name(&self) -> &str

The name of the test.

pub fn path(&self) -> Option<&str>

The path to the source of the test.

pub fn test(&self) -> Option<bool>

Whether or not the test is tested by default by cargo test.

pub fn bench(&self) -> Option<bool>

Whether or not the test is benchmarked by default by cargo bench.

pub fn doc(&self) -> Option<bool>

Whether or not the documentation is built by default by cargo doc for this test.

pub fn harness(&self) -> Option<bool>

Indicates that the test is a test harness.

pub fn edition(&self) -> Option<&str>

The Rust edition this test requires.

pub fn required_features(&self) -> Option<impl Iterator<Item = &str>>

The required features of the test.