pub struct Test<'b> { /* private fields */ }Expand description
A test target.
Implementations
Sourceimpl Test<'_>
impl Test<'_>
Sourcepub fn bench(&self) -> Option<bool>
pub fn bench(&self) -> Option<bool>
Whether or not the test is benchmarked by default by cargo bench.
Sourcepub fn doc(&self) -> Option<bool>
pub fn doc(&self) -> Option<bool>
Whether or not the documentation is built by default by cargo doc for this test.
Sourcepub fn required_features(&self) -> Option<impl Iterator<Item = &str>>
pub fn required_features(&self) -> Option<impl Iterator<Item = &str>>
The required features of the test.